PageUtils class

分页工具类

Constructors

PageUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getStart(int pageNo, int pageSize) int
将页数和每页条目数转换为开始位置
page<T>(int pageNo, int pageSize, List<T>? list) List<T>
列表分页,对给定列表进行分页处理
rainbow(int currentPage, int pageCount, {int displayCount = 10}) List<int>
分页彩虹算法,用于生成分页导航数字
sortPageAll<T>(int pageNo, int pageSize, int comparator(T a, T b)?, List<Iterable<T>> colls) List<T>
多集合排序分页,合并多个集合后进行排序和分页
totalPage(int totalCount, int pageSize) int
根据总数计算总页数
transToStartEnd(int pageNo, int pageSize) List<int>
将页数和每页条目数转换为开始和结束位置