SelectUtils class

Constructors

SelectUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fillSelect<T, S>(List<ISelectBox<T>>? dataList, Iterable<S>? selectList, {Predicate<T?, S?>? predicate, bool maintain = false, bool penetrate = false}) → void
填充选择状态
getSelect<T, S>(List<ISelectBox<T>>? dataList, {List<S>? collection, S convert(ISelectBox<T> event)?, bool penetrate = false}) List<S>?
获取选择的列表
getSelectFromSingle<T>(ISelectBox<T> targetBox, {bool linkage = true}) bool?
获取单个选择框的选中状态
getSelectListWithLinkage<T, S>(List<ISelectBox<T>>? dataList, {List<S>? collection, S convert(ISelectBox<T> event)?}) List<S>?
getSelectWithLinkage<T>(ISelectBox<T> targetBox) bool?
selectAll<T>(List<ISelectBox<T>>? dataList, bool isSelected, {bool penetrate = false}) → dynamic
全选/全不选
toSelect<T, S>(List<T>? dataList, {Iterable<S>? selectList, Predicate<T?, S?>? predicate, bool maintain = false, bool penetrate = false}) List<ISelectBox<T>>
将普通列表转换为选择对象列表