LabelValue<T> class

@author: slc 定义一个泛型类 LabelValue,用于存储标签和对应的值 其中 T 是值的类型,可以是任意类型

Constructors

LabelValue([String? label, T? value])
构造函数,用于创建 LabelValue 实例 label 可选参数,用于初始化标签字段 value 可选参数,用于初始化值字段

Properties

hashCode int
The hash code for this object.
no setterinherited
label String?
标签字段,类型为 String,可空
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T?
值字段,类型为泛型 T,可空
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited