QDateInfo class

@author: slc 定义一个名为 QDateInfo 的类,用于表示日期信息

Constructors

QDateInfo({int? year, int? month, int? day})
构造函数,用于创建 QDateInfo 类的实例 year 可选参数,用于初始化年份 month 可选参数,用于初始化月份 day 可选参数,用于初始化日期

Properties

day int?
日期,为可空的整数类型
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
month int?
月份,为可空的整数类型
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
year int?
年份,为可空的整数类型
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited