ILoadingDialogVmSub class abstract

loading dialog的VM 使用混入引用 @author sunlunchang

Implementers

Constructors

ILoadingDialogVmSub()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismissLoading() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showLoading({String? text}) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited