LoadingDialogVmSub class

Implemented types

Constructors

LoadingDialogVmSub()

Properties

dismissLoadingOf ObservableField<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismissLoading() → dynamic
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setShowLoadingOfFunc(Future showLoadingOfFunc(String?)?) → void
showLoading({String? text}) Future
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited