LoadingDialogWidgetVd class

loading dialog的控件 使用混入引用 @author sunlunchang

Constructors

LoadingDialogWidgetVd()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismissLoadingDialog(BuildContext context) → void
关闭对话框
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerDialogEvent(BuildContext context, LoadingDialogVmSub vmSub) → void
showLoadingDialog(BuildContext context, {bool barrierDismissible = false, String? text}) Future
显示对话框
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited