AbsoluteChangeNotifier class

定义一个自定义的 ChangeNotifier 类 AbsoluteChangeNotifier,用于处理状态变化通知

Inheritance
Implementers

Constructors

AbsoluteChangeNotifier()

Properties

disposed bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
重写 dispose 方法,在销毁时标记 disposed 为 true
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
重写 notifyListeners 方法,只有在未销毁时才通知监听器
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited