MvvmStatelessWidget<T extends BaseVm> class abstract

定义一个抽象的无状态组件类 MvvmStatelessWidget,继承自 StatelessWidget 并混入 MvvmDelegate

Inheritance
Mixed-in types
Implementers

Constructors

MvvmStatelessWidget({Key? key})
构造函数,接收一个可选的 Key 参数

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueWrap ValueWrap<T>
finalinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getVm() → T
获取存储在 ValueWrap 中的 ViewModel 数据
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegisterEventByVm(BuildContext context, T vm) → void
注册事件,子类可重写此方法以处理特定的注册逻辑
inherited
registerEvent(BuildContext context, {bool listen = false}) → void
注册事件,从 Provider 中获取 ViewModel 数据,并调用 onRegisterEventByVm 方法
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited