VmSub class

VmSub 用于为Vm解偶,部分通用业务逻辑放在VmSub处理,并有Vm管理VmSub

Implementers

Constructors

VmSub()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOwnerVm() BaseVm
获取当前 VmSub 的所有者 ViewModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
通知监听器数据变化
onCleared() → void
清除当前 VmSub 的所有者 ViewModel 引用
setOwnerVm(BaseVm ownerVm) → void
设置当前 VmSub 的所有者 ViewModel
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited