FastState<W extends StatefulWidget, T extends FastVm> class abstract

快速状态类,继承自 MvvmState 并混入 StatusWidget

W 继承自 StatefulWidget 的类型参数 T 继承自 FastVm 的类型参数

Inheritance
Mixed-in types

Constructors

FastState({LoadingDialogWidgetVd? loadingDialogWidgetVd, RouterWidgetVd? routerWidgetVd})
构造函数,接收可选的 LoadingDialogWidgetVd 和 RouterWidgetVd 参数

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
loadingDialogWidgetVd LoadingDialogWidgetVd
latefinal
mounted bool
Whether this State object is currently in a tree.
no setterinherited
routerWidgetVd RouterWidgetVd
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueWrap ValueWrap<T>
finalinherited
widget → W
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant W oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
getFailWidget(BuildContext context, {Map<String, dynamic>? params}) Widget
返回一个在失败状态时显示的小部件。
inherited
getLoadingWidget(BuildContext context, {Map<String, dynamic>? params}) Widget
返回一个在加载状态时显示的小部件。
inherited
getStatusBody(BuildContext context, {Map<String, dynamic>? params}) Widget
返回一个根据加载状态显示不同内容的小部件。
inherited
getSuccessWidget(BuildContext context, {Map<String, dynamic>? params}) Widget
返回一个在成功状态时显示的小部件。
inherited
getVm() → T
获取存储在 ValueWrap 中的 ViewModel 数据
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegisterEventByVm(BuildContext context, T vm) → void
注册事件,子类可重写此方法以处理特定的注册逻辑
inherited
onResult(int requestCode, dynamic result) → void
处理结果
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
registerEvent(BuildContext context, {bool listen = false}) → void
注册事件
override
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited