FastStatelessWidget<T extends FastVm> class abstract

@author: slc 快速无状态组件类,继承自 MvvmStatelessWidget 并混入 StatusWidget

T 继承自 FastVm 的类型参数

Inheritance
Mixed-in types

Constructors

FastStatelessWidget({Key? key, LoadingDialogWidgetVd? loadingDialogWidgetVd, RouterWidgetVd? routerWidgetVd})
构造函数,接收可选的 LoadingDialogWidgetVd 和 RouterWidgetVd 参数

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingDialogWidgetVd LoadingDialogWidgetVd
latefinal
routerWidgetVd RouterWidgetVd
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueWrap ValueWrap<T>
finalinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getFailWidget(BuildContext context, {Map<String, dynamic>? params}) Widget
返回一个在失败状态时显示的小部件。
inherited
getLoadingWidget(BuildContext context, {Map<String, dynamic>? params}) Widget
返回一个在加载状态时显示的小部件。
inherited
getStatusBody(BuildContext context, {Map<String, dynamic>? params}) Widget
返回一个根据加载状态显示不同内容的小部件。
inherited
getSuccessWidget(BuildContext context, {Map<String, dynamic>? params}) Widget
返回一个在成功状态时显示的小部件。
inherited
getVm() → T
获取存储在 ValueWrap 中的 ViewModel 数据
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegisterEventByVm(BuildContext context, T vm) → void
注册事件,子类可重写此方法以处理特定的注册逻辑
inherited
onResult(int requestCode, dynamic result) → dynamic
处理结果
registerEvent(BuildContext context, {bool listen = false}) → void
注册事件
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited