FastVm class

快速 ViewModel 类,继承自 BaseVm 并实现多个接口,使Vm拥有Loading、路由、页面状态的能力

Inheritance
Implemented types

Constructors

FastVm()

Properties

disposed bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
loadingDialogVmSub LoadingDialogVmSub
final
routerVmSub RouterVmSub
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusVm StatusVm
final
vmSubList List<VmSub>
finalinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dismissLoading() → dynamic
override
dispose() → void
销毁当前 ViewModel 时调用,清理所有注册的 VmSub
inherited
finish({dynamic result}) → dynamic
override
getLoadingStatus() LoadingStatus
返回当前的加载状态。
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
重写 notifyListeners 方法,只有在未销毁时才通知监听器
inherited
pushNamed(String routeName, {Map<String, dynamic> arguments = const <String, dynamic>{}, Object? extra, int requestCode = 0}) Future
override
pushNamedInfo(SlcRouterInfo slcRouterInfo) Future
override
pushPage(Widget page, {RouteSettings? routeSettings, int requestCode = 0}) Future
override
pushPageParams(PushPageParams startPageParams) Future
override
pushReplacementNamed(String routeName, {Map<String, dynamic> arguments = const <String, dynamic>{}, Object? extra, int requestCode = 0}) Future
override
pushReplacementNamedInfo(SlcRouterInfo slcRouterInfo) Future
override
pushReplacementPage(Widget page, {RouteSettings? routeSettings, int requestCode = 0}) Future
override
pushReplacementPageParams(PushPageParams startPageParams) Future
override
registerVmSub(VmSub? vmSub) → void
注册 VmSub 到当前 ViewModel
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setLoadingStatus(LoadingStatus status) → void
设置加载状态。
override
setLoadingStatusWithNotify(LoadingStatus status, {bool notify = true}) → void
showLoading({String? text}) Future
override
toString() String
A string representation of this object.
inherited
unRegisterVmSub(VmSub? vmSub) → void
从当前 ViewModel 中注销 VmSub
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited