FastVmSub class
快速 VmSub 类,继承自 VmSub 并实现多个接口,使VmSub拥有Loading、路由、页面状态的能力,这些能力由Vm提供
- Inheritance
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dismissLoading(
) → dynamic -
override
-
finish(
{dynamic result}) → dynamic -
override
-
getFastVm(
) → FastVm - 获取 FastVm 实例
-
getLoadingStatus(
) → LoadingStatus -
返回当前的加载状态。
override
-
getOwnerVm(
) → BaseVm -
获取当前 VmSub 的所有者 ViewModel
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
通知监听器数据变化
inherited
-
onCleared(
) → void -
清除当前 VmSub 的所有者 ViewModel 引用
inherited
-
pushNamed(
String routeName, {Map< String, dynamic> arguments = const <String, dynamic>{}, Object? extra, int requestCode = 0}) → Future -
override
-
pushNamedInfo(
SlcRouterInfo slcRouterInfo) → Future -
override
-
pushPage(
Widget page, {RouteSettings? routeSettings, int requestCode = 0}) → Future -
override
-
pushPageParams(
PushPageParams startPageParams) → Future -
override
-
pushReplacementNamed(
String routeName, {Map< String, dynamic> arguments = const <String, dynamic>{}, Object? extra, int requestCode = 0}) → Future -
override
-
pushReplacementNamedInfo(
SlcRouterInfo slcRouterInfo) → Future -
override
-
pushReplacementPage(
Widget page, {RouteSettings? routeSettings, int requestCode = 0}) → Future -
override
-
pushReplacementPageParams(
PushPageParams startPageParams) → Future -
override
-
setLoadingStatus(
LoadingStatus status) → void -
设置加载状态。
override
-
setOwnerVm(
BaseVm ownerVm) → void -
设置当前 VmSub 的所有者 ViewModel
inherited
-
showLoading(
{String? text}) → Future -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
VmSub(
) → dynamic
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited