IStatusVm class abstract

一个状态视图模型的接口。

Implementers

Constructors

IStatusVm()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLoadingStatus() LoadingStatus
返回当前的加载状态。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLoadingStatus(LoadingStatus status) → void
设置加载状态。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited