StatusVm class

一个实现了 IStatusVm 接口的视图模型。

Implemented types

Constructors

StatusVm()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLoadingStatus() LoadingStatus
返回当前的加载状态。
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLoadingStatus(LoadingStatus status) → void
设置加载状态。
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited