ApiConstant class
@author sunlunchang 网络访问中常用到的一些常量
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- KEY_ACCEPT → const String
- KEY_ACCEPT_ENCODING → const String
- KEY_ACCEPT_LANGUAGE → const String
- KEY_ACCEPT_RANGE → const String
- KEY_CACHE_CONTROL → const String
- KEY_CONNECTION → const String
- KEY_CONTENT_DISPOSITION → const String
- KEY_CONTENT_ENCODING → const String
- KEY_CONTENT_LENGTH → const String
- KEY_CONTENT_RANGE → const String
- KEY_CONTENT_TYPE → const String
- KEY_COOKIE → const String
- KEY_DATE → const String
- KEY_E_TAG → const String
- KEY_EXPIRES → const String
- KEY_HOST → const String
- KEY_IF_MODIFIED_SINCE → const String
- KEY_IF_NONE_MATCH → const String
- KEY_LAST_MODIFIED → const String
- KEY_LOCATION → const String
- KEY_RANGE → const String
- KEY_SET_COOKIE → const String
- KEY_USER_AGENT → const String
- VALUE_ACCEPT_ALL → const String
- VALUE_ACCEPT_ENCODING → const String
- VALUE_APPLICATION_FORM → const String
- VALUE_APPLICATION_JSON → const String
- VALUE_APPLICATION_STREAM → const String
- VALUE_APPLICATION_URLENCODED → const String
- VALUE_APPLICATION_XML → const String
- VALUE_CLOSE → const String
- VALUE_KEEP_ALIVE → const String