copyWith method
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
Implementation
@override
ThemeExtension<SlcListTileStyle> copyWith() {
return new SlcListTileStyle();
}
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
@override
ThemeExtension<SlcListTileStyle> copyWith() {
return new SlcListTileStyle();
}