ThemeUtil class

@author: sunlunchang 主题工具类,用户获取一些常用的组件和配置

Constructors

ThemeUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getBoxComfortable({Key? key, Widget? child, double? coverWidth, double? coverHeight}) SizedBox
getBoxCompact({Key? key, Widget? child, double? coverWidth, double? coverHeight}) SizedBox
getBoxCrowded({Key? key, Widget? child, double? coverWidth, double? coverHeight}) SizedBox
getBoxMinimum({Key? key, Widget? child, double? coverWidth, double? coverHeight}) SizedBox
getBoxStandard({Key? key, Widget? child, double? coverWidth, double? coverHeight}) SizedBox
////////////////// SizedBox ///////////////////////
getBrRadius(double? radius) BorderRadius
////////////////// 边框 ///////////////////////
getSizedBox({Key? key, double width = 0, double height = 0}) SizedBox
getSquareBox(double size, {Key? key, Widget? child}) SizedBox

Constants

crowdedDensity → const VisualDensity
////////////////// 视觉密度 ///////////////////////
minimumDensity → const VisualDensity