IRouterVmSub class abstract
loading dialog的VM 使用混入引用 @author sunlunchang
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
finish(
{dynamic result}) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pushNamed(
String routeName, {Map< String, dynamic> arguments = const <String, dynamic>{}, Object? extra, int requestCode = 0}) → Future -
pushNamedInfo(
SlcRouterInfo slcRouterInfo) → Future -
pushPage(
Widget page, {RouteSettings? routeSettings, int requestCode = 0}) → Future -
pushPageParams(
PushPageParams startPageParams) → Future -
pushReplacementNamed(
String routeName, {Map< String, dynamic> arguments = const <String, dynamic>{}, Object? extra, int requestCode = 0}) → Future -
pushReplacementNamedInfo(
SlcRouterInfo slcRouterInfo) → Future -
pushReplacementPage(
Widget page, {RouteSettings? routeSettings, int requestCode = 0}) → Future -
pushReplacementPageParams(
PushPageParams startPageParams) → Future -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited