RouterWidgetVd class

@author: slc 自定义的路由导航器

Constructors

RouterWidgetVd()

Properties

hashCode int
The hash code for this object.
no setterinherited
onResult ↔ dynamic Function(int, dynamic)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPushNamedInfoFunc(BuildContext context, SlcRouterInfo slcRouterInfo) Future
onPushPageParams(BuildContext context, dynamic pushPageParams) Future
onPushReplacementPageParams(BuildContext context, dynamic pushPageParams) Future
onReplacementNamedInfoFunc(BuildContext context, SlcRouterInfo slcRouterInfo) Future
registerRouterEvent(BuildContext context, RouterVmSub routerVm) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited