SlcRouterInfo class

路由信息

Constructors

SlcRouterInfo(String routeName, {Map<String, dynamic> arguments = const <String, dynamic>{}, Map<String, String> queryParameters = const <String, String>{}, Object? data, int requestCode = 0})

Properties

arguments Map<String, dynamic>
getter/setter pair
data Object?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
queryParameters Map<String, String>
getter/setter pair
requestCode int
getter/setter pair
routeName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromInfo(String routeName, {Map<String, dynamic> arguments = const <String, dynamic>{}, Object? data, int requestCode = 0}) SlcRouterInfo