PageModel<T> class
@author: slc 分页模型
Constructors
Properties
- current ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLastPage ↔ bool?
-
getter/setter pair
- pages ↔ int
-
getter/setter pair
-
records
↔ List<
T> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchCount ↔ bool
-
getter/setter pair
- size ↔ int
-
getter/setter pair
- total ↔ int
-
getter/setter pair
Methods
-
getListNoNull(
) → List< T> - 获取非空列表,如果records为空则返回一个可增长的空列表
-
isLastPageSafe(
) → bool - 安全判断是否是最后一页
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited