ISelectBox<T> class
abstract
@author: slc 定义选择框接口
- Implementers
Constructors
Properties
- boxChecked ↔ bool?
-
getter/setter pair
-
boxChildren
↔ List<
T> ? -
getter/setter pair
- boxData ↔ T?
-
getter/setter pair
- boxSelectIndex ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBoxSelectIndex(
) → int - 获取选择索引,如果为空则返回-1
-
isBoxChecked(
) → bool - 获取选中状态,如果为空则返回false
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited