SelectBoxMixin<T> mixin
将 SelectBox 改为可混入的 Mixin
- Implemented types
-
- ISelectBox<
T>
- ISelectBox<
- Mixin applications
Properties
- boxChecked ↔ bool?
-
getter/setter pairoverride
-
boxChildren
↔ List<
T> ? -
getter/setter pairoverride
- boxData ↔ T?
-
接口实现
混入时,data就是本身
getter/setter pairoverride
- boxSelectIndex ↔ int?
-
此处可以是空是为了防止json序列化报错
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBoxSelectIndex(
) → int -
获取选择索引,如果为空则返回-1
override
-
initSelectBox(
{int index = -1, bool checked = false}) → void - 初始化方法(由混入类调用)
-
isBoxChecked(
) → bool -
获取选中状态,如果为空则返回false
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited