ValueWrap<T> class
@author: slc 泛型类 ValueWrap,用于包装一个可能为 null 的泛型数据 T 为泛型类型参数,代表要包装的数据类型
Constructors
- ValueWrap({T? data})
-
构造函数,用于初始化 ValueWrap 实例
data可选参数,用于初始化存储的泛型数据
Properties
- data ↔ T?
-
存储泛型数据的成员变量,允许为 null
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited