ScreenUtil class
Screen Util. @author slc
Constructors
Properties
- bottomBarHeight → double
-
bottom bar Height
no setter
- bottomBarHeightDpr → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenDensity → double
-
screen density
屏幕 像素密度
no setter
- screenHeight → double
-
screen height
屏幕 高
no setter
- screenHeightDpr → double
-
no setter
- screenWidth → double
-
screen width
屏幕 宽
no setter
- screenWidthDpr → double
-
no setter
- statusBarHeight → double
-
status bar Height
状态栏高度
no setter
- statusBarHeightDpr → double
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited