SlcNumUtil class
@author: slc @date: 2025/03/07 基于NumUtil拓展
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getDoubleByValueStr(
String? valueStr, {double? defValue}) → double? - get double by value str.
-
getIntByValueStr(
String? valueStr, {int? defValue}) → int? - get int by value str.
-
getNumByValueStr(
String? valueStr, {int? fractionDigits}) → num? -
The parameter
fractionDigitsmust be an integer satisfying:0 <= fractionDigits <= 20. -
padZeroByValue(
int? valueInt, {bool padRight = true, int? length}) → String? - 输入一个数字不足指定长度的字符串,在前或后面补0
-
padZeroByValueStr(
String? valueStr, {bool padRight = true, int? length}) → String? - 输入一个字符串不足指定长度的字符串,在前或后面补0