StatusWidget<T extends IStatusVm> mixin
@author: slc 一个用于显示不同加载状态的状态小部件混入。
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFailWidget(
BuildContext context, {Map< String, dynamic> ? params}) → Widget - 返回一个在失败状态时显示的小部件。
-
getLoadingWidget(
BuildContext context, {Map< String, dynamic> ? params}) → Widget - 返回一个在加载状态时显示的小部件。
-
getStatusBody(
BuildContext context, {Map< String, dynamic> ? params}) → Widget - 返回一个根据加载状态显示不同内容的小部件。
-
getSuccessWidget(
BuildContext context, {Map< String, dynamic> ? params}) → Widget - 返回一个在成功状态时显示的小部件。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited