SlcDimens class
@author sunlunchang 定义了一些常用的尺寸常量,用于在应用程序中设置不同的尺寸。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- appDimens6 → const double
- appDimens8 → const double
- appDimens12 → const double
- appDimens14 → const double
- appDimens16 → const double
- appDimens18 → const double
- appDimens20 → const double
- appDimens24 → const double
- appDimens28 → const double
- appDimens32 → const double
- appDimens36 → const double