SlcListTileStyle class
定义一个自定义的 ThemeExtension 类 SlcListTileStyle,用于扩展列表项样式
- Inheritance
-
- Object
- ThemeExtension<
SlcListTileStyle> - SlcListTileStyle
Constructors
Properties
Methods
-
copyWith(
) → ThemeExtension< SlcListTileStyle> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
getItemSubTitleStyleByContext(
BuildContext context) → TextStyle -
getItemSubTitleStyleByThemeData(
ThemeData themeData) → TextStyle -
getItemTitleStyleByContext(
BuildContext context) → TextStyle -
getItemTitleStyleByThemeData(
ThemeData themeData) → TextStyle -
lerp(
covariant ThemeExtension< SlcListTileStyle> ? other, double t) → ThemeExtension<SlcListTileStyle> -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited