SlcTidyUpStyle class
定义一个自定义的 ThemeExtension 类 SlcTidyUpStyle,用于扩展主题样式
- Inheritance
-
- Object
- ThemeExtension<
SlcTidyUpStyle> - SlcTidyUpStyle
Constructors
- SlcTidyUpStyle(Divider defLightDivider, Divider defDarkDivider)
- SlcTidyUpStyle.fast(Color lightDividerColor, Color darkDividerColor)
Properties
- defDarkDivider ↔ Divider
-
latefinal
- defLightDivider ↔ Divider
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
) → ThemeExtension< SlcTidyUpStyle> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
getDefDividerByDark(
bool isDark) → Divider -
getDefDividerByTheme(
ThemeData themeData) → Divider -
getLabelFloatTextStyleByDark(
bool isDark) → TextStyle -
getLabelFloatTextStyleByTheme(
ThemeData themeData) → TextStyle? -
getSlcTidyUpColor(
ThemeData themeData) → SlcTidyUpColor -
getTextColorHintStyleByDark(
bool isDark) → TextStyle -
getTextColorHintStyleByTheme(
ThemeData themeData) → TextStyle? -
getTextColorPrimaryStyleByDark(
bool isDark) → TextStyle -
getTextColorPrimaryStyleByTheme(
ThemeData themeData) → TextStyle? -
getTextColorSecondaryStyleByDark(
bool isDark) → TextStyle -
getTextColorSecondaryStyleByTheme(
ThemeData themeData) → TextStyle? -
getTitleTextStyle(
ThemeData themeData) → TextStyle? -
getToolbarTextStyle(
ThemeData themeData) → TextStyle? -
lerp(
covariant ThemeExtension< SlcTidyUpStyle> ? other, double t) → ThemeExtension<SlcTidyUpStyle> -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited